summaryrefslogtreecommitdiffstats
path: root/kmail/jobscheduler.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/jobscheduler.cpp')
-rw-r--r--kmail/jobscheduler.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/jobscheduler.cpp b/kmail/jobscheduler.cpp
index caf4759f..d5374fe4 100644
--- a/kmail/jobscheduler.cpp
+++ b/kmail/jobscheduler.cpp
@@ -34,8 +34,8 @@
using namespace KMail;
-JobScheduler::JobScheduler( TQObject* tqparent, const char* name )
- : TQObject( tqparent, name ), mTimer( this, "mTimer" ),
+JobScheduler::JobScheduler( TQObject* parent, const char* name )
+ : TQObject( parent, name ), mTimer( this, "mTimer" ),
mPendingImmediateTasks( 0 ),
mCurrentTask( 0 ), mCurrentJob( 0 )
{
@@ -109,7 +109,7 @@ void JobScheduler::notifyOpeningFolder( KMFolder* folder )
} else {
// Jobs scheduled from here should always be cancellable.
// One exception though, is when ExpireJob does its final KMMoveCommand.
// Then that command shouldn't kill its own tqparent job just because it opens a folder...
if ( mCurrentJob->isCancellable() )
interruptCurrentTask();
}
@@ -109,7 +109,7 @@ void JobScheduler::notifyOpeningFolder( KMFolder* folder )
// Jobs scheduled from here should always be cancellable.
// One exception though, is when ExpireJob does its final KMMoveCommand.
- // Then that command shouldn't kill its own tqparent job just because it opens a folder...
+ // Then that command shouldn't kill its own parent job just because it opens a folder...
if ( mCurrentJob->isCancellable() )
interruptCurrentTask();